@@ -89,8 +89,11 @@ create_new_row_by_modification <- function(tax_dat,
                                            clear_usage_id = NULL,
                                            fill_usage_name = NULL,
                                            clear_usage_name = NULL,
+                                           remap_parent = NULL,
                                            other_terms = NULL,
-                                           stamp_modified = NULL) {
+                                           stamp_modified = NULL,
+                                           stamp_modified_by_id = NULL,
+                                           stamp_modified_by = NULL) {
   new_row <- tax_dat_row
   # - modify taxonomicStatus
   if (!is.null(tax_status)) {
@@ -108,9 +111,9 @@ create_new_row_by_modification <- function(tax_dat,
   # (so if usage_id is provided and taxonomicStatus includes "accepted",
   # the acceptedNameUsageID will be cleared)
   if (isTRUE(clear_usage_id) &&
-    "taxonomicStatus" %in% colnames(new_row) &&
-    "acceptedNameUsageID" %in% colnames(new_row) &&
-    "acceptedNameUsageID" %in% colnames(tax_dat_row)) {
+        "taxonomicStatus" %in% colnames(new_row) &&
+        "acceptedNameUsageID" %in% colnames(new_row) &&
+        "acceptedNameUsageID" %in% colnames(tax_dat_row)) {
     is_acc <- grepl("accepted", new_row$taxonomicStatus, ignore.case = TRUE)
     if (inherits(tax_dat_row$acceptedNameUsageID, "character") && is_acc) {
       new_row <- dplyr::mutate(new_row, acceptedNameUsageID = NA_character_)
@@ -122,10 +125,10 @@ create_new_row_by_modification <- function(tax_dat,
   # - fill usage name
   usage_name_match <- NULL
   if (isTRUE(fill_usage_name) &&
-    !is.null(usage_id) &&
-    "scientificName" %in% colnames(tax_dat) &&
-    "taxonID" %in% colnames(tax_dat) &&
-    "acceptedNameUsage" %in% colnames(tax_dat_row)) {
+        !is.null(usage_id) &&
+        "scientificName" %in% colnames(tax_dat) &&
+        "taxonID" %in% colnames(tax_dat) &&
+        "acceptedNameUsage" %in% colnames(tax_dat_row)) {
     usage_name_match <- tax_dat$scientificName[tax_dat$taxonID == usage_id]
     assertthat::assert_that(
       isTRUE(length(usage_name_match) == 1),
@@ -145,9 +148,9 @@ create_new_row_by_modification <- function(tax_dat,
   # (so if usage_name is provided and taxonomicStatus includes "accepted",
   # the acceptedNameUsage will be cleared)
   if (isTRUE(clear_usage_name) &&
-    "taxonomicStatus" %in% colnames(new_row) &&
-    "acceptedNameUsage" %in% colnames(new_row) &&
-    "acceptedNameUsage" %in% colnames(tax_dat_row)) {
+        "taxonomicStatus" %in% colnames(new_row) &&
+        "acceptedNameUsage" %in% colnames(new_row) &&
+        "acceptedNameUsage" %in% colnames(tax_dat_row)) {
     is_acc <- grepl("accepted", new_row$taxonomicStatus, ignore.case = TRUE)
     if (inherits(tax_dat_row$acceptedNameUsage, "character") && is_acc) {
       new_row <- dplyr::mutate(new_row, acceptedNameUsage = NA_character_)
@@ -156,6 +159,51 @@ create_new_row_by_modification <- function(tax_dat,
       new_row <- dplyr::mutate(new_row, acceptedNameUsage = NaN)
     }
   }
+  # - change parentNameUsageID to that of the accepted name if it currently
+  #   points to a synonym
+  if (isTRUE(remap_parent) &&
+        "taxonomicStatus" %in% colnames(new_row) &&
+        "parentNameUsageID" %in% colnames(new_row) &&
+        "acceptedNameUsageID" %in% colnames(new_row) &&
+        "taxonID" %in% colnames(tax_dat) &&
+        "taxonomicStatus" %in% colnames(tax_dat) &&
+        "parentNameUsageID" %in% colnames(tax_dat) &&
+        "acceptedNameUsageID" %in% colnames(tax_dat) &&
+        !is.na(new_row$parentNameUsageID)) {
+    parent_row <- tax_dat[tax_dat$taxonID == new_row$parentNameUsageID, ]
+    parent_is_syn <- grepl(
+      "synonym",
+      parent_row$taxonomicStatus, ignore.case = TRUE
+    )
+    if (parent_is_syn) {
+      new_row <- dplyr::mutate(
+        new_row,
+        parentNameUsageID = parent_row$acceptedNameUsageID
+      )
+    }
+  }
+
+  # - change parentNameUsage to that of the accepted name if it currently
+  #   points to a synonym
+  if (isTRUE(remap_parent) &&
+        "parentNameUsageID" %in% colnames(new_row) &&
+        "taxonID" %in% colnames(tax_dat) &&
+        "scientificName" %in% colnames(tax_dat) &&
+        "taxonomicStatus" %in% colnames(tax_dat) &&
+        "parentNameUsage" %in% colnames(tax_dat) &&
+        !is.na(new_row$parentNameUsage)) {
+    # Already modified parentNameUsageID to point to correct (accepted) name,
+    # so don't need to check for that
+    parent_row <- tax_dat[tax_dat$taxonID == new_row$parentNameUsageID, ]
+    parent_name_match <- parent_row$scientificName
+    new_row$parentNameUsage <- parent_name_match
+    # Need parent_name_match later, so store as attribute
+    attributes(new_row) <- c(
+      attributes(new_row),
+      parent_name_match = parent_name_match
+    )
+  }
+
   # - add other DwC terms, overwriting existing values
   if (!is.null(other_terms)) {
     if (nrow(other_terms) > 0) {
@@ -172,6 +220,31 @@ create_new_row_by_modification <- function(tax_dat,
       modified = as.character(Sys.time())
     )
   }
+
+  # Add modifiedBy
+  if (isTRUE(stamp_modified_by)) {
+    assertthat::assert_that(
+      isTRUE("modifiedBy" %in% dct_options()$extra_cols),
+      msg = "stamp_modified_by requires 'modifiedBy' in extra_cols"
+    )
+    new_row <- dplyr::mutate(
+      new_row,
+      modifiedBy = dct_options()$user_name
+    )
+  }
+
+  # Add modifiedByUserID
+  if (isTRUE(stamp_modified_by_id)) {
+    assertthat::assert_that(
+      isTRUE("modifiedByID" %in% dct_options()$extra_cols),
+      msg = "stamp_modified_by_id requires 'modifiedByID' in extra_cols"
+    )
+    new_row <- dplyr::mutate(
+      new_row,
+      modifiedByID = dct_options()$user_id
+    )
+  }
+
   return(new_row)
 }
 
@@ -189,11 +262,16 @@ create_new_row_by_modification <- function(tax_dat,
 change_other_rows <- function(tax_dat,
                               tax_dat_row,
                               usage_name_match = NULL,
+                              parent_name_match = NULL,
                               usage_id = NULL,
+                              parent_id = NULL,
                               remap_names = NULL,
+                              remap_parent = NULL,
                               remap_variant = NULL,
                               fill_usage_name = NULL,
-                              stamp_modified = NULL) {
+                              stamp_modified = NULL,
+                              stamp_modified_by_id = NULL,
+                              stamp_modified_by = NULL) {
   new_row_other <- NULL
   if (!is.null(usage_id) && isTRUE(remap_names)) {
     # - find other rows affected
@@ -210,6 +288,7 @@ change_other_rows <- function(tax_dat,
     }
     # - update other rows affected
     if (nrow(new_row_other) > 0) {
+      # Update acceptedNameUsageID
       new_row_other <- dplyr::mutate(
         new_row_other,
         acceptedNameUsageID = usage_id
@@ -220,12 +299,48 @@ change_other_rows <- function(tax_dat,
           acceptedNameUsage = usage_name_match
         )
       }
+      # Remap parent
+      if (isTRUE(remap_parent)) {
+        new_row_other <- dplyr::mutate(
+          new_row_other,
+          parentNameUsageID = parent_id
+        )
+      }
+      if (isTRUE(remap_parent) && !is.null(parent_name_match)) {
+        new_row_other <- dplyr::mutate(
+          new_row_other,
+          parentNameUsage = parent_name_match
+        )
+      }
+      # Add modified time stamp
       if (isTRUE(stamp_modified)) {
         new_row_other <- dplyr::mutate(
           new_row_other,
           modified = as.character(Sys.time())
         )
       }
+      # Add modifiedBy
+      if (isTRUE(stamp_modified_by)) {
+        assertthat::assert_that(
+          isTRUE("modifiedBy" %in% dct_options()$extra_cols),
+          msg = "stamp_modified_by requires 'modifiedBy' in extra_cols"
+        )
+        new_row_other <- dplyr::mutate(
+          new_row_other,
+          modifiedBy = dct_options()$user_name
+        )
+      }
+      # Add modifiedByUserID
+      if (isTRUE(stamp_modified_by_id)) {
+        assertthat::assert_that(
+          isTRUE("modifiedByID" %in% dct_options()$extra_cols),
+          msg = "stamp_modified_by_id requires 'modifiedByID' in extra_cols"
+        )
+        new_row_other <- dplyr::mutate(
+          new_row_other,
+          modifiedByID = dct_options()$user_id
+        )
+      }
     }
   }
   return(new_row_other)
@@ -331,8 +446,13 @@ dct_modify_row_single <- function(tax_dat,
                                   fill_usage_name =
                                     dct_options()$fill_usage_name,
                                   remap_names = dct_options()$remap_names,
+                                  remap_parent = dct_options()$remap_parent,
                                   remap_variant = dct_options()$remap_variant,
                                   stamp_modified = dct_options()$stamp_modified,
+                                  stamp_modified_by_id =
+                                    dct_options()$stamp_modified_by_id,
+                                  stamp_modified_by =
+                                    dct_options()$stamp_modified_by,
                                   strict = dct_options()$strict,
                                   quiet = dct_options()$quiet,
                                   other_terms = NULL) {
@@ -372,6 +492,7 @@ dct_modify_row_single <- function(tax_dat,
   assertthat::assert_that(assertthat::is.flag(clear_usage_id))
   assertthat::assert_that(assertthat::is.flag(fill_usage_name))
   assertthat::assert_that(assertthat::is.flag(remap_names))
+  assertthat::assert_that(assertthat::is.flag(remap_parent))
   assertthat::assert_that(assertthat::is.flag(remap_variant))
   assertthat::assert_that(assertthat::is.flag(stamp_modified))
   assertthat::assert_that(assertthat::is.flag(strict))
@@ -428,13 +549,23 @@ dct_modify_row_single <- function(tax_dat,
     clear_usage_id = clear_usage_id,
     fill_usage_name = fill_usage_name,
     clear_usage_name = clear_usage_name,
+    remap_parent = remap_parent,
     other_terms = other_terms,
-    stamp_modified = stamp_modified
+    stamp_modified = stamp_modified,
+    stamp_modified_by_id = stamp_modified_by_id,
+    stamp_modified_by = stamp_modified_by
   )
 
   # Extract usage_name_match from new_row, which is stored as an attribute
   usage_name_match <- attributes(new_row)$usage_name_match
   attributes(new_row)$usage_name_match <- NULL
+  parent_name_match <- attributes(new_row)$parent_name_match
+  attributes(new_row)$parent_name_match <- NULL
+  parent_id <- if ("parentNameUsageID" %in% colnames(new_row)) {
+    new_row$parentNameUsageID
+  } else {
+    NULL
+  }
 
   # Change other rows
   # For change to synonym or variety (acceptedNameUsageID not NA),
@@ -443,11 +574,16 @@ dct_modify_row_single <- function(tax_dat,
     tax_dat = tax_dat,
     tax_dat_row = tax_dat_row,
     usage_name_match = usage_name_match,
+    parent_name_match = parent_name_match,
     usage_id = usage_id,
+    parent_id = parent_id,
     remap_names = remap_names,
+    remap_parent = remap_parent,
     remap_variant = remap_variant,
     fill_usage_name = fill_usage_name,
-    stamp_modified = stamp_modified
+    stamp_modified = stamp_modified,
+    stamp_modified_by_id = stamp_modified_by_id,
+    stamp_modified_by = stamp_modified_by
   )
 
   # Format output
@@ -486,10 +622,17 @@ dct_modify_row_single <- function(tax_dat,
 #' If `remap_names` is `TRUE` (default) and `acceptedNameUsageID` is provided,
 #' any names that have an acceptedNameUsageID matching the taxonID of the
 #' selected row (i.e., synonyms of that row) will also have their
-#' acceptedNameUsageID replaced with the new acceptedNameUsageID. This behavior
+#' acceptedNameUsageID replaced with the new acceptedNameUsageID. This applies
+#' to `acceptedNameUsage` as well. This behavior
 #' is not applied to names with taxonomicStatus of "variant" by default, but can
 #' be turned on for such names with `remap_variant`.
 #'
+#' If `remap_parent` is `TRUE` (default) and the `parentNameUsageID` of the
+#' selected row is a synonym, the `parentNameUsageID` will be changed to
+#' that of the accepted name (of the parent taxon). This will also apply to any
+#' other row with the same `parentNameUsageID` as the selected row. This applies
+#' to `parentNameUsage` as well.
+#'
 #' If `clear_usage_id` or `clear_usage_name` is `TRUE` and `taxonomicStatus`
 #' includes the word "accepted", acceptedNameUsageID
 #' or acceptedNameUsage will be set to NA respectively, regardless of the
@@ -516,8 +659,11 @@ dct_modify_row_single <- function(tax_dat,
 #' @param clear_usage_name `r param_clear_usage_id`
 #' @param fill_usage_name `r param_fill_usage_name`
 #' @param remap_names `r param_remap_names`
+#' @param remap_parent `r param_remap_parent`
 #' @param remap_variant `r param_remap_variant`
 #' @param stamp_modified `r param_stamp_modified`
+#' @param stamp_modified_by_id `r param_stamp_modified_by_id`
+#' @param stamp_modified_by `r param_stamp_modified_by_name`
 #' @param strict `r param_strict`.
 #' @param quiet `r param_quiet`.
 #' @param args_tbl A dataframe including columns corresponding to one or more of
@@ -543,8 +689,13 @@ dct_modify_row <- function(tax_dat,
                            clear_usage_name = dct_options()$clear_usage_name,
                            fill_usage_name = dct_options()$fill_usage_name,
                            remap_names = dct_options()$remap_names,
+                           remap_parent = dct_options()$remap_parent,
                            remap_variant = dct_options()$remap_variant,
                            stamp_modified = dct_options()$stamp_modified,
+                           stamp_modified_by_id =
+                             dct_options()$stamp_modified_by_id,
+                           stamp_modified_by =
+                             dct_options()$stamp_modified_by,
                            strict = dct_options()$strict,
                            quiet = dct_options()$quiet,
                            args_tbl = NULL,
@@ -596,8 +747,15 @@ dct_modify_row <- function(tax_dat,
         clear_usage_name = val_if_in_dat(args_tbl, "clear_usage_name", i),
         fill_usage_name = val_if_in_dat(args_tbl, "fill_usage_name", i),
         remap_names = val_if_in_dat(args_tbl, "remap_names", i),
+        remap_parent = val_if_in_dat(args_tbl, "remap_parent", i),
         remap_variant = val_if_in_dat(args_tbl, "remap_variant", i),
         stamp_modified = val_if_in_dat(args_tbl, "stamp_modified", i),
+        stamp_modified_by_id = val_if_in_dat(
+          args_tbl, "stamp_modified_by_id", i
+        ),
+        stamp_modified_by = val_if_in_dat(
+          args_tbl, "stamp_modified_by", i
+        ),
         strict = val_if_in_dat(args_tbl, "strict", i),
         quiet = quiet,
         other_terms = args_tbl[i, !colnames(args_tbl) %in% std_args]
@@ -618,8 +776,11 @@ dct_modify_row <- function(tax_dat,
     clear_usage_name = clear_usage_name,
     fill_usage_name = fill_usage_name,
     remap_names = remap_names,
+    remap_parent = remap_parent,
     remap_variant = remap_variant,
     stamp_modified = stamp_modified,
+    stamp_modified_by_id = stamp_modified_by_id,
+    stamp_modified_by = stamp_modified_by,
     strict = strict,
     quiet = quiet,
     other_terms = tibble::tibble(...)
