@@ -29,6 +29,13 @@ param_check_mapping_parent <- glue::glue(
   {print_default("check_mapping_parent")}.'
 )
 
+param_check_mapping_parent_accepted <- glue::glue( # nolint
+  'Logical vector of length 1; should all values of \\
+  `parentNameUsageID` be required to map to the `taxonID` of an accepted \\
+  name? \\
+  {print_default("check_mapping_parent_accepted")}.'
+)
+
 param_check_mapping_original <- glue::glue(
   'Logical vector of length 1; should all values of \\
   `originalNameUsageID` be required to map to the `taxonID` of an existing \\
@@ -133,6 +140,28 @@ param_stamp_modified <- glue::glue(
   {print_default("stamp_modified")}.'
 )
 
+param_stamp_modified_by_name <- glue::glue(
+  'Logical vector of length 1; should the `modifiedBy` \\
+  column of any newly created or modified row include the name of the
+  current user? \\
+  If the `modifiedBy` column does not yet exist it will be created; note that
+  this is a non-DWC standard column, so `"modifiedBy"` is required in
+  `extra_cols`. \\
+  The current user can be specified with the `user_name` option. \\
+  {print_default("stamp_modified_by")}.'
+)
+
+param_stamp_modified_by_id <- glue::glue(
+  'Logical vector of length 1; should the `modifiedByID` \\
+  column of any newly created or modified row include the ID of the
+  current user? \\
+  If the `modifiedByID` column does not yet exist it will be created; note that
+  this is a non-DWC standard column, so `"modifiedByID"` is required in
+  `extra_cols`. \\
+  The current user ID can be specified with the `user_id` option. \\
+  {print_default("stamp_modified_by_id")}.'
+)
+
 param_fill_usage_name <- glue::glue(
   'Logical vector of length 1; should the \\
   acceptedNameUsage of the selected row be set to the \\
@@ -161,6 +190,14 @@ param_remap_names <- glue::glue(
   {print_default("remap_names")}.'
 )
 
+param_remap_parent <- glue::glue(
+  'Logical vector of length 1; should the parentNameUsageID be updated \\
+  (remapped) to that of its accepted name if it is a synonym? \\
+  Will also apply to any other rows with the same \\
+  parentNameUsageID as the taxonID of the row to be modified. \\
+  {print_default("remap_names")}.'
+)
+
 param_remap_variant <- glue::glue(
   'Same as `remap_names`, but applies specifically to \\
   rows with taxonomicStatus of "variant". \\
@@ -173,6 +210,16 @@ param_skip_missing_cols <- glue::glue(
   {print_default("skip_missing_cols")}.'
 )
 
+param_user_name <- glue::glue(
+  'Character vector of length 1; the name of the current user. \\
+  {print_default("user_name", quote = TRUE)}.'
+)
+
+param_user_id <- glue::glue(
+  'Character vector of length 1; the ID of the current user. \\
+  {print_default("user_id", quote = TRUE)}.'
+)
+
 # Check that default values of both clear_usage_name and
 # clear_usage_id are TRUE
 check_fill_usage_id_name <- function() {
